/*---------------------------------------------------------------------\
|                                                                      |
|                     _     _   _   _     __     _                     |
|                    | |   | | | \_/ |   /  \   | |                    |
|                    | |   | | | |_| |  / /\ \  | |                    |
|                    | |__ | | | | | | / ____ \ | |__                  |
|                    |____||_| |_| |_|/ /    \ \|____|                 |
|                                                                      |
|                             nfs-server library                       |
|                                                                      |
|                                         (C) SUSE Linux Products GmbH |
|                                         (C) Novell, Inc.             |
\----------------------------------------------------------------------/

  File:       config.h

  Author:     Marius Tomaschewski, Chakravarthi P
  Maintainer: Chakravarthi P

/-*/
/**
 * @file config.h
 * This is config file, where we declare the namespace
 * and compilation time definitions, like our version.
 */
#ifndef   nfs_server_config_h
#define   nfs_server_config_h

#include <limal/config.h>


/**
 * LiMaL nfs-server library version.
 */
#ifndef LIMAL_NFS_SERVER_LIB_VERSION
#define LIMAL_NFS_SERVER_LIB_VERSION		"1.4.2"
#endif


/**
 * LiMaL nfs-server API/namespace version.
 */
#ifndef LIMAL_NFS_SERVER_API_VERSION
#define LIMAL_NFS_SERVER_API_VERSION		1
#endif


/**
 * LiMaL nfs-server namespace definition
 * with appended API version number.
 */
#ifndef NFS_SERVER_NAMESPACE
#define NFS_SERVER_NAMESPACE \
	LIMAL_DEFINE_NAMESPACE(nfs_server, LIMAL_NFS_SERVER_API_VERSION)
#endif /* NFS_SERVER_NAMESPACE */


/**
 * @namespace limal::nfs_server
 * The LiMaL nfs_server namespace is only a alias.
 * The real namespace is defined in the @file config.h
 * file to a namespace with appended API version number.
 */
#ifdef    __cplusplus
namespace LIMAL_NAMESPACE
{
    namespace NFS_SERVER_NAMESPACE
    {
    }
    namespace nfs_server = NFS_SERVER_NAMESPACE;
}
#endif /* __cplusplus */


#ifdef    __cplusplus
extern "C" {
#endif /* __cplusplus */

/**
 * LiMaL nfs-server lib version number function.
 * @returns library version string
 */
const char * limal_nfs_server_lib_version();


/**
 * LiMaL nfs-server API version number function.
 * @returns library API version number
 */
unsigned int limal_nfs_server_api_version();

#ifdef    __cplusplus
}
#endif /* __cplusplus */


#endif /* nfs_server_config_h  */

